
library(tidyverse)
library(RefManageR)
source("R/release_functions.R")

# path to build folder
build_path <- "../austraits.build"

# read data
v <- "0.9.0"
austraits <- readRDS(sprintf("%s/export/data/austraits_%s.rds", build_path, v))

# fix SHA
(austraits$build_info$git_SHA <- austraits$build_info$git_SHA %>% str_sub(2, 41))

# Remove studies not ready for release 
to_remove <- c(
               # Still clarifying permissions
               "Venn_2011", 
               "Specht_1958",
               "Morgan_2005"
               
               # Large updates and restructure pending 
               "Richards_2008",
               "ANBG_2018", 
               "AusGrass_2014", 
               "Clayton_2006",
               "RBGSYD_2014",
               "Kew_2010",
               "Kew_2012",
               "Osbourne_2014"
               )
for(s in to_remove)
  austraits <- remove_study(s, austraits)

# Ensure build repo is at right SHA
build.git <- git2r::init(build_path)
git2r::checkout(build.git, austraits$build_info$git_SHA )
git2r::sha(git2r::last_commit(build.git)) == austraits$build_info$git_SHA

# add contributor info from build
contributors <- 
  austraits$traits$dataset_id %>% 
  unique() %>% 
  lapply(function(x) 
    yaml::read_yaml(sprintf("%s/data/%s/metadata.yml", build_path, x))$people %>%
      list_to_df() %>% 
      mutate(dataset_id = x) %>% 
      select(dataset_id, everything())  
  ) %>% 
  bind_rows() %>% 
  filter(!is.na(name))

austraits$contributors <- contributors

# Export
export_to_plain_text(austraits, v)
