
<!-- README.md is generated from README.Rmd. Please edit that file -->

![](docs/logo.png)

# `AusTraits`: a curated plant trait database for the Australian flora

<!-- badges: start -->

[![DOI](https://zenodo.org/badge/210490673.svg)](https://zenodo.org/badge/latestdoi/210490673)
<!-- badges: end -->

## Introduction

AusTraits is a transformative database, containing measurements on the
traits of Australia’s plant species, standardised from hundreds of
disconnected primary sources. So far, data have been assembled from 139
distinct sources, describing more than 80 plant traits and over 19k
species. A full list of sources is provided below.

To handle the harmonising of diverse data sources, we use a reproducible
workflow to implement the various changes required for each source to
reformat it suitable for incorporation in AusTraits. Such changes
include restructuring datasets, renaming variables, changing variable
units, changing taxon names. While this repository contains the
harmonised data, the raw data and code used to build the resource will
also be made available,

## Contributors

The project is jointly led by Dr Daniel Falster (University of New South
Wales, Sydney) and Dr Rachael Gallagher (Macquarie University), with
input from 127 contributors from over 59 institutions.

The following people and institutions have have contributed to building
this resource.

**Data contributors (individuals)**: Mark Adams, Tara Angevin, Anthony
Bean, Biloni, Chris Blackman, Eleanor Bolza, David Bowman, Jason Bragg,
Amber Briggs, John Brock, Jeff Burley, Geoff Burrows, Don Butler,
Carter, Jane A. Catford, Gregory Chandler, Alex Chapman, Si-Chong Chen,
Nguyen Ngoc Chinh, Robert Chinnock, David Christophel, Martin Chudnoff,
Peter Clarke, Harold Trevor Clifford, Wendy Cooper, William Cooper, Ian
Cowie, Lyn Craven, Michael Crisp, Erika Cross, Saul Cunningham, Ian
Davidson, Matthew Denton, Desch, Dimitri, David Duncan, Marco Duretto,
John M. Dwyer, Derek Eamus, Rebel Elick, John Evans, James Flynn, Carlos
Fonseca, Paul Irwin Forster, Sean Gleason, Ethel Goble-Garratt,
Goldsmith, Bruce Gray, Caroline Gross, Peter Grubb, Matthew Harrison,
Foteini Hassiotou, Heady, Martin Henery, Lesley Hughes, Kate Hughes,
John Huisman, Bernie Hyland, Muhammad Islam, Greg Jordan, Enrique
Jurado, Greg Keighery, Juergen Kellerman, Kirsten Knox, Robert Kooyman,
Etienne Laliberte, Hans Lambers, Byron Lamont, Daniel C. Laughlin,
Michael Lawes, Emma Laxton, Caroline Lehmann, Michelle Leishman, Brendan
Lepschi, Margaret Lewington, Janice Lord, Ian Lunt, Christopher Lusk,
Anthony Manea, Neville Marchant, Abdurahim Martawijaya, Bruce Maslin,
Robert Mason, James McCarthy, Daniel Metcalfe, Angela Moles, John
Morgan, Huw Morgan, Andrew O’Reilly-Nugent, Grazyna Paczkowska, Paula
Peeters, Burak Pekin, Lynda Prior, Jenny Read, Barbara Rice, Anna
Richards, Bryan Roberts, Barbara Rye, Miguel de Salas, Susanne Schmidt,
Ernst-Detlef Schulze, Andrew John Scott, Oey Djoen Seng, Santiago
Soliveres, Jan Suda, Ian Thompson, David Tng, H. Toelken, Kyle
Tomlinson, Malcolm Trudgeon, Erik Veneklaas, Peter Vesk, Mark Westoby,
Judith Wheeler,Trevor Whiffin, Peter Wilson, Ian Wright & Amy Zanne

**Data contributors (institutions)**: Australian National Botanic
Garden, Brisbane Rainforest Action and Information Network, Kew Botanic
Gardens, National Herbarium of NSW, Northern Territory Herbarium,
Queensland Herbarium, Western Australian Herbarium, South Australian
Herbarium, State Herbarium of South Australia, Tasmanian Herbarium

**Data processing**: Daniel Falster, Elizabeth Wenk, Caitlan Baxter, Sam
Andrew, James Lawson, Stuart Allen

**Project initiation and data compilation**: Rachael Gallagher, Ian
Wright

**Funding**: Gallagher has been supported by MQRF grant from Macquarie
University and a DECRA fellowship from the Australian Research Council
(DE170100208). Falster has been supported by a grant from the Science
and Industry Endowment Fund Grant (RP04-174) and a Future fellowship
from the ARC (FT160100113). We are grateful for additional funding from
the Australian Research Data Commons which greatly enhanced the range of
datasets included.

## Accessing and use of data

AusTraits will be released under an open source licence (CC-BY),
enabling re-use by the community, once our paper describing the data
resource becomes public (in 2020). In the meantime, access to the the
data resource is restricted.

A requirement of use is that users cite the AusTraits resource paper,
which includes all contributors as co-authors:

> Citation pending

In addition, we encourage users you to cite the original data sources,
wherever possible.

## Contributing

We envision AusTraits as an on-going collaborative community resource
that:

1.  Increases our collective understanding the Australian flora; and
2.  Facilitates accumulating and sharing of trait data;
3.  Builds a sense of community among contributors and users; and
4.  Aspires to fully transparent and reproducible research of highest
    standard.

As a community resource, we are very keen for people to contribute. Here
are some of the ways you can contribute:

**Reporting Errors**: If you notice a possible error in AusTraits,
please [post an issue on
GitHub](https://github.com/traitecoevo/austraits.build/issues) .

**Refining documentation:** We welcome additions and edits that make
using the existing data or adding new data easier for the community.

**Contributing new data**: We gladly accept new data contributions to
AusTraits. For full instructions on preparing data for inclusion in
AusTraits, please got to
<https://github.com/traitecoevo/austraits.build>.

## Structure of AusTraits data

The compiled AusTraits database has the following main components:

    austraits
    ├── traits
    ├── sites
    ├── methods
    ├── excluded_data
    ├── taxonomy
    ├── definitions
    ├── contributors
    └── build_info

These elements include all the data and contextual information submitted
with each contributed datasets.

Full details on each of these components and columns therein are
contained within the document `Austraits_dictionary.html` and within the
file `definitions.yml`.

## Original sources

The current version of AusTraits includes data from the following
sources:

  - T. Angevin. “Unpublished data: Trait data collected via
    Honoursproject at La Trobe University”. 2010.
  - B. A. Barlow, H. T. Clifford, A. S. George, and A. K. A.McCusker.
    *Flora of Australia (online)*. 1981. url:
    <http://www.environment.gov.au/biodiversity/abrs/online-resources/flora/main/>.
  - A. Bean. “A revision of Baeckea (Myrtaceae) in easternAustralia,
    Malesia and south-east Asia”. *Telopea* 7 (1997),pp. 245-268. doi:
    [10.1.1.520.6315\&rep=rep1\&type=pdf](https://doi.org/10.1.1.520.6315%26rep%3Drep1%26type%3Dpdf).
  - Forest Department of Burma. *Standard nomenclature of forestplants,
    Burma, including commercial timbers*. Forest Research andTraining
    Circle, Forest Department, Burma, 1974.
  - C. J. Blackman, S. M. Gleason, Y. Chang, A. M. Cook, C. Laws,and M.
    Westoby. “Leaf hydraulic vulnerability to drought is linkedto site
    water availability across a broad range of species andclimates”.
    *Annals of Botany* 114 (2014), pp. 435-440. doi:
    [10.1093/aob/mcu131](https://doi.org/10.1093%2Faob%2Fmcu131).
  - E. Bolza. *Properties and uses of 175 timber species from PapuaNew
    Guinea and West Irian*. Victoria (Australia) CSIRO, Div. ofBuilding
    Research, 1975.
  - J. G. Bragg and M. Westoby. “Leaf size and foraging for lightin a
    sclerophyll woodland”. *Functional Ecology* 16 (2002),pp. 633-639.
    doi:
    [10.1046/j.1365-2435.2002.00661.x](https://doi.org/10.1046%2Fj.1365-2435.2002.00661.x).
  - Brisbane Rainforest Action & Information Network. *Traitmeasurements
    for Australian rainforest species*. 2016. url:
    <http://www.brisrain.org.au/>.
  - A. L. Briggs and J. W. Morgan. “Seed characteristics and soilsurface
    patch type interact to affect germination of semi-aridwoodland
    species”. *Plant Ecol* 212 (2010), pp. 91-103. doi:
    [10.1007/s11258-010-9806-x](https://doi.org/10.1007%2Fs11258-010-9806-x).
  - J. Brock and A. Dunlop. *Native plants of northern
    Australia*.Frenchs Forest, N.S.W.: Reed New Holland, 1993.
    <ISBN:9781877069246>.
  - G. E. Burrows. “Comparative anatomy of the photosyntheticorgans of
    39 xeromorphic species from subhumid New South Wales,Australia”.
    *International Journal of Plant Sciences* 162(2001), pp. 411-430.
    doi: [10.1086/319579](https://doi.org/10.1086%2F319579).
  - D. W. Butler, S. M. Gleason, I. Davidson, Y. Onoda, and M.Westoby.
    “Safety and streamlining of woody shoots in wind: Anempirical
    study across 39 species in tropical Australia”. *NewPhytologist* 193
    (2011), pp. 137-149. doi:
    [10.1111/j.1469-8137.2011.03887.x](https://doi.org/10.1111%2Fj.1469-8137.2011.03887.x).
  - CAB International. *Forestry Compendium*. 2009. url:
    <http://www.cabi.org/fc/>.
  - J. A. Catford, W. K. Morris, P. A. Vesk, C. J. Gippel, and B.J.
    Downes. “Species and environmental characteristics point toflow
    regulation and drought as drivers of riparian plantinvasion”.
    *Diversity and Distributions* 20 (2014), pp.1084-1096. doi:
    [10.1111/ddi.12225](https://doi.org/10.1111%2Fddi.12225).
  - G. T. Chandler, M. D. Crisp, L. W. Cayzer, and R. J.
    Bayer.“Monograph of Gastrolobium (Fabaceae: Mirbelieae)”.
    *Australian Systematic Botany* 15 (2002), p. 619. doi:
    [10.1071/sb01010](https://doi.org/10.1071%2Fsb01010).
  - J. Chave, D. Coomes, S. Jansen, S. L. Lewis, N. G. Swenson, andA. E.
    Zanne. “Towards a worldwide wood economics spectrum”. *Ecology
    Letters* 12 (2009), pp. 351-366. doi:
    [10.1111/j.1461-0248.2009.01285.x](https://doi.org/10.1111%2Fj.1461-0248.2009.01285.x).
  - S. Chen and A. T. Moles. “A mammoth mouthful? A test of theidea that
    larger animals ingest larger seeds”. *Global Ecologyand
    Biogeography* 24 (2015), pp. 1269-1280. doi:
    [10.1111/geb.12346](https://doi.org/10.1111%2Fgeb.12346).
  - N. N. Chính. *Vietnam forest trees*. Forest Inventory andPlanning
    Institute Agricultural Publishing House Hanoi, 1999.ISBN:
    19996775635.
  - R. J. Chinnock. *Eremophila and allied genera: A monograph ofthe
    plant family Myoporaceae*. Dural, NSW: Rosenberg, 2007.
    <ISBN:9781877058165>.
  - M. Chudnoff. *Tropical timbers of the world*. US Department
    ofAgriculture, Forest Service, 1984, p. 472. ISBN: 3935638825.
  - The French agricultural research & international
    cooperationorganization (CIRAD). *Wood density data*. 2009. url:
    <http://www.cirad.fr/>.
  - W. Cooper and W. T. Cooper. *Fruits of the Australian
    tropicalrainforest*. Nokomis Editions, 2004. ISBN: 9780958174213.
  - Centre for Plant Biodiversity Research. *EUCLID 2.0: Eucalyptsof
    Australia*. 2002.
  - L. Craven. “A taxonomic Revision of Calytrix Labill.(Myrtaceae)”.
    *Brunonia* 10 (1987), pp. 1-138. doi:
    [10.1071/bru9870001](https://doi.org/10.1071%2Fbru9870001).
  - L. A. Craven, B. J. Lepschi, and K. J. Cowley. “Melaleuca(Myrtaceae)
    of Western Australia: Five new species, three newcombinations, one
    new name and a new state record.”. \_Nuytsia\_20 (2010), pp. 27-36.
  - E. Cross. “Unpublished data: Woodlands of western Victoriatrait
    database”. 2011.
  - M. D. Crisp. “Notes on Daviesia and Jacksonia
    (Leguminosae:Papilionoideae) for the flora of the Perth region”.
    \_Nuytsia\_5 (1984), pp. 159-170.
  - S. A. Cunningham, B. Summerhayes, and M. Westoby.
    “Evolutionarydivergences in leaf structure and chemistry,
    comparing rainfalland soil nutrient gradients”. *Ecological
    Monographs* 69(1999), pp. 569-588. doi:
    [10.1890/0012-9615(1999)069\[0569:EDILSA\]2.0.CO;2](https://doi.org/10.1890%2F0012-9615%281999%29069%5B0569%3AEDILSA%5D2.0.CO%3B2).
  - M. D. Denton, E. J. Veneklaas, F. M. Freimoser, and H.
    Lambers.“Banksia species (Proteaceae) from
    severelyphosphorus-impoverished soils exhibit extreme efficiency in
    theuse and re-mobilization of phosphorus”. *Plant, Cell
    andEnvironment* 30 (2007), pp. 1557-1565. doi:
    [10.1111/j.1365-3040.2007.01733.x](https://doi.org/10.1111%2Fj.1365-3040.2007.01733.x).
  - H. E. Desch and J. M. Dinwoodie. *Timber structure,
    properties,conversion and use*. Palgrave Macmillan, 1996. ISBN:
    156022861X.
  - M. Dimitri and J. Biloni. *Libro del árbol. Vol 1.
    Esenciasforestales indígenas de la Argentina; and Vol 2.
    EsenciasForestales indígenas de la Argentina de aplicación
    industrial*.Editorial Celulosa Argentina S. A., 1973.
  - D. H. Duncan. “Unpublished data: Leaf anatomy of Australianplant
    species”. 1998.
  - J. M. Dwyer and D. C. Laughlin. “Constraints on traitcombinations
    explain climatic drivers of biodiversity: Theimportance of trait
    covariance in community assembly”. *Ecology Letters* 20.7 (2017),
    pp. 872-882. doi:
    [10.1111/ele.12781](https://doi.org/10.1111%2Fele.12781).
  - D. Eamus and H. Prichard. “A cost-benefit analysis of leaves offour
    Australian savanna species”. *Tree Physiology* 18
    (1998),pp. 537-545. doi:
    [10.1093/treephys/18.8-9.537](https://doi.org/10.1093%2Ftreephys%2F18.8-9.537).
  - D. Eamus, B. Myers, G. Duff, and D. Williams. “Seasonal changesin
    photosynthesis of eight savanna tree species”. *TreePhysiology* 19
    (1999), pp. 665-671. doi:
    [10.1093/treephys/19.10.665](https://doi.org/10.1093%2Ftreephys%2F19.10.665).
  - C. Edwards, G. D. Sanson, N. Aranwela, and J. Read.“Relationships
    between sclerophylly, leaf biomechanical propertiesand leaf anatomy
    in some Australian heath and forest species”. *Plant Biosystems - An
    International Journal Dealing with allAspects of Plant Biology* 134
    (2000), pp. 261-277. doi:
    [10.1080/11263500012331350445](https://doi.org/10.1080%2F11263500012331350445).
  - D. S. Falster and M. Westoby. “Alternative height strategiesamong 45
    dicot rain forest species from tropical Queensland,Australia”.
    *Journal of Ecology* 93 (2005), pp. 521-535. doi:
    [10.1111/j.0022-0477.2005.00992.x](https://doi.org/10.1111%2Fj.0022-0477.2005.00992.x).
  - D. S. Falster and M. Westoby. “Tradeoffs between height growthrate,
    stem persistence and maximum height among plant species in
    apost-fire succession”. *Oikos* 111 (2005), pp. 57-66. doi:
    [10.1111/j.0030-1299.2005.13383.x](https://doi.org/10.1111%2Fj.0030-1299.2005.13383.x).
  - J. H. Flynn and C. D. Holder. *A guide to useful woods of theworld*.
    2nd. Forest Products Society, 2001. ISBN: 1892529157.
  - C. R. Fonseca, J. M. Overton, B. Collins, and M. Westoby.“Shifts in
    trait-combinations along rainfall and phosphorusgradients”. *Journal
    of Ecology* 88 (2000), pp. 964-977. doi:
    [10.1046/j.1365-2745.2000.00506.x](https://doi.org/10.1046%2Fj.1365-2745.2000.00506.x).
  - P. I. Forster. “A taxonomic revision of Alyxia (Apocynaceae)
    inAustralia”. *Australian Systematic Botany* 5 (1992), pp.547-580.
    doi: [10.1071/sb9920547](https://doi.org/10.1071%2Fsb9920547).
  - P. I. Forster. “New names and combinations in
    Marsdenia(Asclepiadaceae: Marsdenieae) from Asia and Malesia
    (excludingPapusia)”. *Australian Systematic Botany* 8 (1995),
    pp.691-701. doi:
    [10.1071/sb9950691](https://doi.org/10.1071%2Fsb9950691).
  - R. V. Gallagher, M. R. Leishman, J. T. Miller, C. Hui, D.
    M.Richardson, J. Suda, and P. Trávníček. “Invasiveness in
    introducedAustralian acacias: The role of species traits and genome
    size”. *Diversity and Distributions* 17 (2011), pp. 884-897. doi:
    [10.1111/j.1472-4642.2011.00805.x](https://doi.org/10.1111%2Fj.1472-4642.2011.00805.x).
  - S. M. Gleason, D. W. Butler, K. Zieminska, P. Waryszak, and
    M.Westoby. “Stem xylem conductivity is key to plant water
    balanceacross Australian angiosperm species”. *Functional Ecology*
    26(2012), pp. 343-352. doi:
    [10.1111/j.1365-2435.2012.01962.x](https://doi.org/10.1111%2Fj.1365-2435.2012.01962.x).
  - E. Goble-Garratt, D. Bell, and W. Loneragan. “Floristic andleaf
    structure patterns along a shallow elevational gradient”.
    *Australian Journal of Botany* 29 (1981), p. 329. doi:
    [10.1071/bt9810329](https://doi.org/10.1071%2Fbt9810329).
  - B. Goldsmith and D. Carter. *The indigenous timbers ofZimbabwe*. 9.
    1981, p. 406. ISBN: 0869232940.
  - C. L. Gross. “The reproductive ecology of Canavalia rosea(Fabaceae)
    on Anak Krakatau, Indonesia”. *Australian Journalof Botany* 41
    (1993), p. 591. doi:
    [10.1071/bt9930591](https://doi.org/10.1071%2Fbt9930591).
  - P. J. Grubb and D. J. Metcalfe. “Adaptation and inertia in
    theAustralian tropical lowland rain-forest flora:
    Contradictorytrends in intergeneric and intrageneric comparisons of
    seed sizein relation to light demand”. *Functional Ecology* 10
    (1996),p. 512. doi:
    [10.2307/2389944](https://doi.org/10.2307%2F2389944).
  - P. J. Grubb, R. V. Jackson, I. M. Barberis, J. N. Bee, D. A.Coomes,
    N. J. Dominy, M. A. S. D. L. Fuente, P. W. Lucas, D. J.Metcalfe, J.
    Svenning, I. M. Turner, and O. Vargas. “Monocotleaves are eaten less
    than dicot leaves in tropical lowland rainforests: Correlations with
    toughness and leaf presentation”. *Annals of Botany* 101 (2008),
    pp. 1379-1389. doi:
    [10.1093/aob/mcn047](https://doi.org/10.1093%2Faob%2Fmcn047).
  - M. T. Harrison, E. J. Edwards, G. D. Farquhar, A. B. Nicotra,and J.
    R. Evans. “Nitrogen in cell walls of sclerophyllous leavesaccounts
    for little of the variation in photosyntheticnitrogen-use
    efficiency”. *Plant, Cell and Environment* 32(2009), pp. 259-270.
    doi:
    [10.1111/j.1365-3040.2008.01918.x](https://doi.org/10.1111%2Fj.1365-3040.2008.01918.x).
  - F. Hassiotou, J. R. Evans, M. Ludwig, and E. J. Veneklaas.“Stomatal
    crypts may facilitate diffusion of CO2 to adaxialmesophyll cells in
    thick sclerophylls”. *Plant, Cell andEnvironment* 32 (2009),
    pp. 1596-1611. doi:
    [10.1111/j.1365-3040.2009.02024.x](https://doi.org/10.1111%2Fj.1365-3040.2009.02024.x).
  - M. L. Henery and M. Westoby. “Seed mass and seed nutrientcontent as
    predictors of seed output variation between species”. *Oikos* 92
    (2001), pp. 479-490. doi:
    [10.1034/j.1600-0706.2001.920309.x](https://doi.org/10.1034%2Fj.1600-0706.2001.920309.x).
  - L. Hong, R. Lemmens, S. Prawirohatmodjo, I. Soerianegara, M.Sosef,
    and W. W. (Editors). *Plant resources of south east Asia:Timber
    trees*. Springer-Verlag Berlin and Heidelberg GmbH & Co.KG, 1999,
    p. World biodiversity Database CD rom series. <ISBN:9783540147732>.
  - L. Hughes and B. Rice. “Unpublished data: Traits data for
    643species”. 1992.
  - K. Hughes. “Unpublished data: Wood and stem density data
    forAustralian plant species”. 2005.
  - B. P. M. Hyland, T. Whiffin, D. Christophel, B. Gray, and R.
    W.Elick. *Australian tropical rain forest plants trees, shrubs
    andvines*. CSIRO Publishing, 2003. ISBN: 0643068724.
  - World Agroforestry Centre (ICRAF). *The wood density database*.2009.
    url:
    <http://www.worldagroforestry.org/output/wood-density-database>.
  - J. Ilic, D. Boland, M. McDonald, D. G, and P. Blakemore.
    *Woodydensity phase 1 - State of Knowledge. National Carbon
    AccountingSystem. Technical Report 18*. Tech. rep. Australian
    GreenhouseOffice, Canberra, Australia., 2000.
  - M. Islam, D. W. Turner, and M. A. Adams. “Phosphorusavailability and
    the growth, mineral composition and nutritivevalue of ephemeral
    forbs and associated perennials from thePilbara, Western Australia”.
    *Australian Journal ofExperimental Agriculture* 39 (1999),
    pp. 149-159. doi:
    [10.1071/EA98133](https://doi.org/10.1071%2FEA98133).
  - M. Islam and M. Adams. “Mineral content and nutritive value ofnative
    grasses and the response to added phosphorus in a Pilbararangeland”.
    *Tropical Grasslands* 33 (1999), pp. 193-200.
  - G. Jordan. “Unpublished data: Leaf traits for Tasmanianspecies”.
    2007.
  - E. Jurado. “Diaspore weight, dispersal, growth form andperenniality
    of central Australian plants”. *Journal ofEcology* 79 (1993),
    pp. 811-828. url: <https://www.jstor.org/stable/2260669>.
  - G. Keighery. “Taxonomy of the Calytrix ecalycata
    complex(Myrtaceae)”. *Nuytsia* 15 (2004), pp. 261-268. url:
    <https://florabase.dpaw.wa.gov.au/nuytsia/article/409>.
  - K. J. E. Knox and P. J. Clarke. “Fire severity and
    nutrientavailability do not constrain resprouting in forest shrubs”.
    *Plant Ecol* 212 (2011), pp. 1967-1978. doi:
    [10.1007/s11258-011-9956-5](https://doi.org/10.1007%2Fs11258-011-9956-5).
  - R. Kooyman, M. Rossetto, W. Cornwell, and M. Westoby.“Phylogenetic
    tests of community assembly across regional tocontinental scales in
    tropical and subtropical rain forests”. *Global Ecology and
    Biogeography* 20 (2011), pp. 707-716. doi:
    [10.1111/j.1466-8238.2010.00641.x](https://doi.org/10.1111%2Fj.1466-8238.2010.00641.x).
  - E. L. é, B. L. Turner, T. Costes, S. J. Pearse, K. Wyrwoll,
    G.Zemunik, and H. Lambers. “Experimental assessment of
    nutrientlimitation along a 2-million-year dune chronosequence in
    thesouth-western Australia biodiversity hotspot”. *Journal
    ofEcology* 100 (2012), pp. 631-642. doi:
    [10.1111/j.1365-2745.2012.01962.x](https://doi.org/10.1111%2Fj.1365-2745.2012.01962.x).
  - B. B. Lamont, P. K. Groom, and R. M. Cowling. “High leaf massper
    area of related species assemblages may reflect low rainfalland
    carbon isotope discrimination rather than low phosphorus andnitrogen
    concentrations”. *Functional Ecology* 16 (2002), pp.403-412. doi:
    [10.1046/j.1365-2435.2002.00631.x](https://doi.org/10.1046%2Fj.1365-2435.2002.00631.x).
  - M. J. Lawes, J. J. Midgley, and P. J. Clarke. “Costs andbenefits of
    relative bark thickness in relation to fire damage: Asavanna/forest
    contrast”. *Journal of Ecology* 101 (2012), pp.517-524. doi:
    [10.1111/1365-2745.12035](https://doi.org/10.1111%2F1365-2745.12035).
  - E. Laxton. “Relationship between leaf traits, insectcommunities and
    resource availability”. PhD thesis. MacquarieUniversity, 2005. url:
    <http://hdl.handle.net/1959.14/483>.
  - M. R. Leishman and M. Westoby. “Classifying plants into groupson the
    basis of associations of individual traits-Evidence fromAustralian
    semi-arid woodlands”. *Journal of Ecology* 80(1992), p. 417. doi:
    [10.2307/2260687](https://doi.org/10.2307%2F2260687).
  - M. Leishman. “Unpublished data: Seed mass data for Sydneyspecies”.
    1993.
  - M. R. Leishman, M. Westoby, and E. Jurado. “Correlates of seedsize
    variation: A comparison among five temperate floras”. *Journal of
    Ecology* 83 (1995), pp. 517-529. doi:
    [10.2307/2261604](https://doi.org/10.2307%2F2261604).
  - I. Davidson. “Unpublished data: SLA data for 76 acacia speciesfrom
    glasshouse seedlings”. 2011.
  - R. V. Gallagher, M. R. Leishman, J. T. Miller, C. Hui, D.
    M.Richardson, J. Suda, and P. Trávníček. “Invasiveness in
    introducedAustralian acacias: the role of species traits and genome
    size”. *Diversity and Distributions* 17 (2011), pp. 884-897. doi:
    [10.1111/j.1472-4642.2011.00805.x](https://doi.org/10.1111%2Fj.1472-4642.2011.00805.x).
  - R. Lemmens and I. Soerjanegara. *PROSEA, Volume 5/1: TimberTrees -
    Major Commercial Timbers*. Pudoc/Prosea, 1993. <ISBN:9789022010334>.
  - J. Lord, J. Egan, T. Clifford, E. Jurado, M. Leishman, D.Williams,
    and M. Westoby. “Larger seeds in tropical floras:Consistent patterns
    independent of growth form and dispersalmode”. *Journal of
    Biogeography* 24 (1997), pp. 205-211. doi:
    [10.1046/j.1365-2699.1997.00126.x](https://doi.org/10.1046%2Fj.1365-2699.1997.00126.x).
  - I. Lunt and J. Morgan. “Unpublished data: Trait data fromvarious
    Morgan and Lunt projects 1990-2012”. 2012.
  - C. H. Lusk, J. W. G. Kelly, and S. M. Gleason. “Lightrequirements of
    Australian tropical vs. cool-temperate rainforesttree species show
    different relationships with seedling growth andfunctional traits”.
    *Annals of Botany* 111 (2012), pp.479-488. doi:
    [10.1093/aob/mcs289](https://doi.org/10.1093%2Faob%2Fmcs289).
  - A. Manea. “Unpublished data: Dispersal appendage data foracacia via
    worldwide wattle”. 2011.
  - A. Martawijaya, I. Kartasujana, K. Kadir, and S. A.
    Prawira.\_Indonesian wood atlas vol. I. and II\_. AFPRDC AFRD
    Department ofForestry,, 1992.
  - B. Maslin. *WATTLE Acacias of Australia*. 2012.
  - J. McCarthy. “Predicting the diversity and functionalcomposition of
    woody plant communities under climate change”. PhDthesis. University
    of Queensland, 2017.
  - E. Meier. *The wood database*. 2007. url:
    <http://www.wood-database.com/>.
  - J. Morgan. “Unpublished data: Grassy woodland traits”. 2011.
  - J. Morgan. “Unpublished data: Trait database”. 2011.
  - J. Morgan. “Unpublished data: Trait data from Australian
    plantspecies”. 2004.
  - H. Morgan. “Root system architecture, water use and
    rainfallrepsonses of perennial species”. PhD thesis. Macquarie
    University,2005.
  - National Herbarium of NSW. *Trait measurements for NSWrainforest
    species from PlantNET*. 2016. url:
    <http://plantnet.rbgsyd.nsw.gov.au/>.
  - Ü. Niinemets, I. J. Wright, and J. R. Evans. “Leaf
    mesophylldiffusion conductance in 35 Australian sclerophylls
    covering abroad range of foliage structural and physiological
    variation”. *Journal of Experimental Botany* 60 (2009),
    pp. 2433-2449. doi:
    [10.1093/jxb/erp045](https://doi.org/10.1093%2Fjxb%2Ferp045).
  - Northern Territory Herbarium. *Flora of the Darwin RegionOnline*.
    2014. url:
    <http://www.lrm.nt.gov.au/plants-and-animals/herbarium/darwin_flora_online>.
  - A. O’Reilly-Nugent, E. Wandrag, C. Catford, B. Gruber, D.Driscoll,
    and R. Duncan. *Measuring impact: Joint-speciesmodelling of invaded
    plant communities*. 2018.
  - P. J. Peeters. “Correlations between leaf structural traits andthe
    densities of herbivorous insect guilds”. *BiologicalJournal of the
    Linnean Society* 77 (2002), pp. 43-65. doi:
    [10.1046/j.1095-8312.2002.00091.x](https://doi.org/10.1046%2Fj.1095-8312.2002.00091.x).
  - B. K. Pekin, R. S. Wittkuhn, M. M. Boer, C. Macfarlane, and P.F.
    Grierson. “Plant functional traits along environmentalgradients in
    seasonally dry and fire-prone ecosystem”. *Journal of Vegetation
    Science* 22 (2011), pp. 1009-1020. doi:
    [10.1111/j.1654-1103.2011.01323.x](https://doi.org/10.1111%2Fj.1654-1103.2011.01323.x).
  - L. D. Prior, D. Eamus, and D. M. J. S. Bowman. “Leaf attributesin
    the seasonally dry tropics: A comparison of four habitats innorthern
    Australia”. *Functional Ecology* 17 (2003), pp.504-515. doi:
    [10.1046/j.1365-2435.2003.00761.x](https://doi.org/10.1046%2Fj.1365-2435.2003.00761.x).
  - Oxford Forestry Institute. *Prospect: The wood database*. 2009. url:
    <http://dps.plants.ox.ac.uk/ofi/prospect/index.htm>.
  - Royal Botanic Gardens Kew. *Seed Information Database (SID)*.2014.
    url: <http://data.kew.org/sid/>.
  - Royal Botanic Gardens Sydney. *PlantNet: NSW flora online*.2014.
    url: <http://plantnet.rbgsyd.nsw.gov.au/>.
  - B. Rice. “Unpublished data: Growth form of Kakadu plantspecies”.
    1991.
  - A. Richards, A. Shapcott, J. Playford, B. Morrison, C.Critchley, and
    S. Schmidt. “Physiological profiles of restrictedendemic plants and
    their widespread congenors in the NorthQueensland wet tropics,
    Australia”. \_Biological Conservation\_111 (2003), pp. 41-52. doi:
    [10.1016/s0006-3207(02)00245-8](https://doi.org/10.1016%2Fs0006-3207%2802%2900245-8).
  - B. Roberts. “Unpublished data”. 2006.
  - B. Rye. “A revision of south-western Australian species
    ofMicromyrtus (Myrtaceae) with five antisepalous ribs on
    thehypanthium.”. *Nuytsia* 15 (2002), pp. 101-122.
  - B. Rye. “A partial revision of the south-western Australianspecies
    of Micromyrtus (Myrtaceae: Chamelaucieae)”. \_Nuytsia\_16 (2006),
    pp. 117-147.
  - B. Rye. “Reinstatement of the Western Australian genusOxymyrrhine
    (Myrtaceae: Chamelaucieae) with three new species”. *Nuytsia* 19
    (2009), pp. 149-165. url:
    <https://florabase.dpaw.wa.gov.au/science/nuytsia/468.pdf>.
  - B. L. Rye. “A revision of the Micromyrtus racemosa
    complex(Myrtaceae: Chamelaucieae) of south-western Australia”.
    *Nuytsia* 20 (2010), pp. 37-56.
  - B. Rye, P. Wilson, and G. Keighery. “A revision of the speciesof
    Hypocalymma (Myrtaceae: Chamelaucieae) with smooth orcolliculate
    seeds”. *Nuytsia* 23 (2013), pp. 283-312. url:
    <https://florabase.dpaw.wa.gov.au/science/nuytsia/672.pdf>.
  - B. L. Rye. “An update to the taxonomy of some westernAustralian
    genera of Myrtaceae tribe Chamelaucieae. 1. Calytrix”. *Nuytsia* 23
    (2013), pp. 483-501. url:
    <https://florabase.dpaw.wa.gov.au/science/nuytsia/687.pdf>.
  - B. L. Rye. “A revision of the south-western Australian
    genusBabingtonia (Myrtaceae: Chamelaucieae).”. *Nuytsia* 25
    (2015),pp. 219-250. url:
    <https://florabase.dpaw.wa.gov.au/science/nuytsia/758.pdf>.
  - South Australian Herbarium. *Flora of South Australia, Volume4*.
    2014.
  - S. Schmidt and G. R. Stewart. “d15N values of tropical savannaand
    monsoon forest species reflect root specialisations and soilnitrogen
    status”. *Oecologia* 134 (2003), pp. 569-577. doi:
    [10.1007/s00442-002-1150-y](https://doi.org/10.1007%2Fs00442-002-1150-y).
  - E. Schulze. “Unpublished data: Traits of plant species alongthe
    Northern Australian Transect Study”. 2008.
  - A. J. Scott. “Unpublished data: Honours Project at La
    TrobeUniversity”. 2010.
  - O. D. Seng. *Specific gravity of Indonesian Woods and
    itssignificance for practical use*. Tech. rep. FPRDC
    ForestryDepartment, Bogor, Indonesia, 1951.
  - S. Soliveres, D. J. Eldridge, F. Hemmings, and F. T. Maestre.“Nurse
    plant effects on plant species richness in drylands: Therole of
    grazing, rainfall and species specificity”. *Perspectives in Plant
    Ecology, Evolution and Systematics* 14(2012), pp. 402-410. doi:
    [10.1016/j.ppees.2012.09.003](https://doi.org/10.1016%2Fj.ppees.2012.09.003).
  - I. R. Thompson. “Morphometric analysis and revision of
    easternAustralian Hovea (Brongniartieae-Fabaceae)”.
    *AustralianSystematic Botany* 14 (2001), p. 1. doi:
    [10.1071/sb00008](https://doi.org/10.1071%2Fsb00008).
  - Tasmanian Herbarium. *Flora of Tasmania Online*. 2009. url:
    [www.tmag.tas.gov.au/floratasmania](www.tmag.tas.gov.au/floratasmania).
  - D. Y. P. Tng, G. J. Jordan, and D. M. J. S. Bowman. “Planttraits
    demonstrate that temperate and tropical giant Eucalyptforests are
    ecologically convergent with rainforest not savanna”. *PLoS ONE* 8
    (2013), p. e84378. doi:
    [10.1371/journal.pone.0084378](https://doi.org/10.1371%2Fjournal.pone.0084378).
  - H. Toelken. “A revision of the genus Kunzea (Myrtaceae) I.
    Thewestern Australian section Zeanuk”. *Journal of the
    AdelaideBotanic Garden* 17 (1996), pp. 29-106.
  - K. W. Tomlinson, L. Poorter, F. J. Sterck, F. Borghetti, D.Ward, S.
    de Bie, and F. van Langevelde. “Leaf adaptations ofevergreen and
    deciduous trees of semi-arid and humid savannas onthree continents”.
    *Journal of Ecology* 101 (2013), pp.430-440. doi:
    [10.1111/1365-2745.12056](https://doi.org/10.1111%2F1365-2745.12056).
  - M. Trudgeon and B. Rye. “Astus, a new western Australian genusof
    Myrtaceae with heterocarpidic fruits”. *Nuytsia* 14
    (2005),pp. 495-512.
  - M. Trudgen and B. Rye. “An update to the taxonomy of somewestern
    Australian genera of Myrtaceae tribe Chamelaucieae. 2.Cyathostemon”.
    *Nuytsia* 24 (2014), pp. 7-16. url:
    <https://florabase.dpaw.wa.gov.au/science/nuytsia/692.pdf>.
  - P. A. Vesk, D. I. Warton, and M. Westoby. “Sprouting bysemi-arid
    plants: Testing a dichotomy and predictive traits”. *Oikos* 107
    (2004), pp. 72-89. doi:
    [10.1111/j.0030-1299.2004.13122.x](https://doi.org/10.1111%2Fj.0030-1299.2004.13122.x).
  - P. Vesk. “Unpublished data: Leaf traits for flora of FallsCreek
    Victoria”. 2007.
  - Western Australian Herbarium. *FloraBase: the westernAustralian
    flora*. 1998. url: <https://florabase.dpaw.wa.gov.au/>.
  - Western Australian Herbarium. *FloraBase: the westernAustralian
    flora*. 2016. url: <https://florabase.dpaw.wa.gov.au/>.
  - J. Wells. “Unpublished data: Wood density data for global
    wooddensity database”. 2009.
  - M. Westoby and I. J. Wright. “The leaf size - twig sizespectrum and
    its relationship to other important spectra ofvariation among
    species”. *Oecologia* 135 (2003), pp. 621-628. doi:
    [10.1007/s00442-003-1231-6](https://doi.org/10.1007%2Fs00442-003-1231-6).
  - M. Westoby. “Unpublished data: Trait data for plant species atMt
    Wellington and Sea Acres”. Collected while at MacquarieUniversity.
    2004.
  - M. Westoby. “Unpublished data: SLA data for various plantspecies”.
    1996.
  - J. R. Wheeler, N. G. Marchant, and M. Lewington. *Flora of thesouth
    west: Bunbury, Augusta, Denmark*. Canberra, A.C.T. :Crawley, W.A:
    Australian Biological Resources Study ; Universityof Western
    Australia Press, 2002. ISBN: 9780642568168.
  - P. G. Wilson and R. Rowe. “A revision of the Indigofereae(Fabaceae)
    in Australia. 2. Indigofera species with trifoliolateand alternately
    pinnate leaves”. *Telopea* 12 (2008), pp.293-307.
  - I. J. Wright, H. T. Clifford, R. Kidson, M. L. Reed, B. L.Rice, and
    M. Westoby. “A survey of seed and seedling characters in1744
    Australian dicotyledon species: Cross-species traitcorrelations and
    correlated trait-shifts within evolutionarylineages”. *Biological
    Journal of the Linnean Society* 69(2000), pp. 521-547. doi:
    [10.1111/j.1095-8312.2000.tb01222.x](https://doi.org/10.1111%2Fj.1095-8312.2000.tb01222.x).
  - I. J. Wright. “Unpublished data: Seed mass reserve data forvarious
    species in NSW”. 2001.
  - I. J. Wright and M. Westoby. “Leaves at low versus highrainfall:
    Coordination of structure, lifespan and physiology”. *New
    Phytologist* 155 (2002), pp. 403-416. doi:
    [10.1046/j.1469-8137.2002.00479.x](https://doi.org/10.1046%2Fj.1469-8137.2002.00479.x).
  - I. J. Wright, P. B. Reich, M. Westoby, D. D. Ackerly, Z.Baruch, F.
    Bongers, J. Cavender-Bares, T. Chapin, J. H. C.Cornelissen, M.
    Diemer, J. Flexas, E. Garnier, P. K. Groom, J.Gulias, K. Hikosaka,
    B. B. Lamont, T. Lee, W. Lee, C. Lusk, J. J.Midgley, M. Navas, Ü.
    Niinemets, J. Oleksyn, N. Osada, H. Poorter,P. Poot, L. Prior, V. I.
    Pyankov, C. Roumet, S. C. Thomas, M. G.Tjoelker, E. J. Veneklaas,
    and R. Villar. “The worldwide leafeconomics spectrum”. *Nature* 428
    (2004), pp. 821-827. doi:
    [10.1038/nature02403](https://doi.org/10.1038%2Fnature02403).
  - I. J. Wright, D. S. Falster, M. Pickup, and M.
    Westoby.“Cross-species patterns in the coordination between leaf
    and stemtraits, and their implications for plant hydraulics”.
    *Physiologia Plantarum* 127 (2006), pp. 445-456. doi:
    [10.1111/j.1399-3054.2006.00699.x](https://doi.org/10.1111%2Fj.1399-3054.2006.00699.x).
  - I. Wright. “Unpublished data: Trait data for Northern
    Territorysavanna species”. 2008.
  - A. Zanne. “Unpublished data: Hydraulic traits for NSW plantspecies
    from four field sites”. 2007.
  - A. E. Zanne, G. Lopez-Gonzalez, D. A. Coomes, J. Ilic, S.Jansen, S.
    L. Lewis, R. B. Miller, N. G. Swenson, M. C. Wiemann,and J. Chave.
    *Data from: Towards a worldwide wood economicsspectrum*. 2009. doi:
    [10.5061/dryad.234](https://doi.org/10.5061%2Fdryad.234).
